pub struct PhysicsAgent { /* private fields */ }Expand description
The agent responsible for managing the physics simulation.
It acts as the Control Plane (ISA) for the physics subsystem, deciding which strategies (lanes) to deploy and managing the physics world.
Implementations
Sourceimpl PhysicsAgent
impl PhysicsAgent
Sourcepub fn new(provider: Box<dyn PhysicsProvider>) -> Self
pub fn new(provider: Box<dyn PhysicsProvider>) -> Self
Creates a new PhysicsAgent with a given provider.
Sourcepub fn with_telemetry(self, registry: &MetricsRegistry) -> Self
pub fn with_telemetry(self, registry: &MetricsRegistry) -> Self
Attaches a metrics registry to the agent for observability.
Sourcepub fn with_dcc_sender(self, sender: Sender<TelemetryEvent>) -> Self
pub fn with_dcc_sender(self, sender: Sender<TelemetryEvent>) -> Self
Attaches a DCC sender for telemetry events.
Sourcepub fn select_lane(&self) -> &dyn Lane
pub fn select_lane(&self) -> &dyn Lane
Selects the appropriate physics lane based on the current strategy.
Sourcepub fn cast_ray(
&self,
ray: &Ray,
max_toi: f32,
solid: bool,
) -> Option<RaycastHit>
pub fn cast_ray( &self, ray: &Ray, max_toi: f32, solid: bool, ) -> Option<RaycastHit>
Exposes raycasting from the provider.
Sourcepub fn get_debug_render_data(&self) -> (Vec<Vec3>, Vec<[u32; 2]>)
pub fn get_debug_render_data(&self) -> (Vec<Vec3>, Vec<[u32; 2]>)
Returns debug rendering data from the provider.
Sourcepub fn last_step_time(&self) -> Duration
pub fn last_step_time(&self) -> Duration
Returns the duration of the last step.
Sourcepub fn frame_count(&self) -> u64
pub fn frame_count(&self) -> u64
Returns the total number of frames simulated.
Sourcepub fn current_strategy_id(&self) -> StrategyId
pub fn current_strategy_id(&self) -> StrategyId
Returns the current GORNA strategy ID.
Sourcepub fn fixed_timestep(&self) -> f32
pub fn fixed_timestep(&self) -> f32
Returns the current fixed timestep.
Sourcepub fn set_fixed_timestep(&mut self, dt: f32)
pub fn set_fixed_timestep(&mut self, dt: f32)
Sets the fixed timestep.